# Superstocks
Unified AI trading platform powered by human intelligence.

## References

1. [LikeFolio](https://developer.twitter.com/en/community/success-stories/likefolio) - LikeFolio uses Twitter data to gain unique financial insights for investors.
2. [SMA](https://developer.twitter.com/en/community/success-stories/sma) - SMA uses derived analytics to forecast more effectively in volatile markets.
3. [Smallcase](https://www.smallcase.com/) - A smallcase is a basket of stocks that reflects an idea.
4. [Kya Trade](https://www.kyatrade.com/) - KyaTrade instantly identifies and streams tons of trading and investing ideas so that you can trade opportunities from anywhere and anytime of the day.
